<?php
/**
 * An interface for node-information (database) wrapper
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface NodeInformationWrapper extends DatabaseWrapper {
	/**
	 * 'Registers' a new node id along with data provided in the node instance.
	 * This may sound confusing but avoids double code very nicely...
	 *
	 * @param	$nodeInstance		A node instance
	 * @param	$requestInstance	An instance of a Requestable class
	 * @return	void
	 */
	function registerNodeId (BaseHubNode $nodeInstance, Requestable $requestInstance);

	/**
	 * 'Registers' a new session id along with data provided in the node instance.
	 * This may sound confusing but avoids double code very nicely...
	 *
	 * @param	$nodeInstance		An instance of a BaseHubNode class
	 * @param	$requestInstance	An instance of a Requestable class
	 * @param	$searchInstance		An instance of a LocalSearchCriteria class
	 * @return	void
	 */
	function registerSessionId (BaseHubNode $nodeInstance, Requestable $requestInstance, LocalSearchCriteria $searchInstance);

	/**
	 * 'Registers' a private key  along with data provided in the node instance.
	 * This may sound confusing but avoids double code very nicely...
	 *
	 * @param	$nodeInstance		An instance of a BaseHubNode class
	 * @param	$requestInstance	An instance of a Requestable class
	 * @param	$searchInstance		An instance of a LocalSearchCriteria class
	 * @return	void
	 */
	function registerPrivateKey (BaseHubNode $nodeInstance, Requestable $requestInstance, LocalSearchCriteria $searchInstance);
}

// [EOF]
?>
