<?php
/**
 * A factory class for communicator
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2014, 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class CommunicatorFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a singleton communicator instance. If no instance is found, it fill
	 * be generated and stored in registry, else the communicator from the
	 * registry will be returned.
	 *
	 * @param	$configEntry			A configuration entry naming the real class' name
	 * @parasm	$communicatorType		Type of the communicator, can currently be 'node'
	 * @return	$communicatorInstance	A communicator instance
	 */
	public static final function createCommunicatorInstance ($configEntry, $communicatorType) {
		// If there is no communicator?
		if (Registry::getRegistry()->instanceExists($communicatorType . '_communicator')) {
			// Get communicator from registry
			$communicatorInstance = Registry::getRegistry()->getInstance($communicatorType . '_communicator');
		} else {
			// Get the communicator instance
			$communicatorInstance = self::createObjectByConfiguredName($configEntry);

			// Add it to the registry
			Registry::getRegistry()->addInstance($communicatorType . '_communicator', $communicatorInstance);
		}

		// Return the instance
		return $communicatorInstance;
	}
}

// [EOF]
?>
