<?php
/**
 * A factory class for package assembler
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class PackageAssemblerFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a singleton assembler instance. If no instance is found, it fill
	 * be generated and stored in registry, else the assembler from the
	 * registry will be returned.
	 *
	 * @param	$packageInstance	An instance of a Receivable instance
	 * @return	$assemblerInstance	An instance of a Assembler instance
	 */
	public static final function createAssemblerInstance (Receivable $packageInstance) {
		// If there is no assembler?
		if (Registry::getRegistry()->instanceExists('package_assembler')) {
			// Get assembler from registry
			$assemblerInstance = Registry::getRegistry()->getInstance('package_assembler');
		} else {
			// Get the assembler instance
			$assemblerInstance = self::createObjectByConfiguredName('package_assembler_class', array($packageInstance));

			// Add it to the registry
			Registry::getRegistry()->addInstance('package_assembler', $assemblerInstance);
		}

		// Return the instance
		return $assemblerInstance;
	}
}

// [EOF]
?>
