<?php
/**
 * A factory class for node states
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class NodeStateFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of a configurable node state and sets it in the
	 * given node instance.
	 *
	 * @param	$stateName		Name of the state
	 * @param	$nodeInstance	An instance of a NodeHelper class (optional)
	 * @return	$stateInstance	A Stateable class instance
	 */
	public static final function createNodeStateInstanceByName ($stateName, NodeHelper $nodeInstance = NULL) {
		// Then construct the class' configuraton entry
		$className = 'node_' . $stateName . '_state_class';

		// Is the node instance set?
		if (is_null($nodeInstance)) {
			// Get node instance from registry
			$nodeInstance = NodeObjectFactory::createNodeInstance();
		} // END - if

		// Get a class from that configuration entry
		$stateInstance = self::createObjectByConfiguredName($className, array($nodeInstance));

		// Debug message
		self::createDebugInstance(__CLASS__)->debugOutput('NODE-STATE-FACTORY[' . __METHOD__ . ':' . __LINE__ . ']: Node state has changed from ' . $nodeInstance->getPrintableState() . ' to ' . $stateInstance->getStateName() . '.');

		// Once we have that state, set it in the node instance
		$nodeInstance->setStateInstance($stateInstance);

		// Update node data
		$nodeInstance->updateNodeData();

		// For any purposes, return the state instance
		return $stateInstance;
	}
}

// [EOF]
?>
