<?php
/**
 * A Initialization filter for apt-proxy
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2011 - 2012 Apt-Proxy Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class AptProxyInitializationFilter extends BaseAptProxyFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public static final function createAptProxyInitializationFilter () {
		// Get a new instance
		$filterInstance = new AptProxyInitializationFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @todo	0% done
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get an instance
		$proxyInstance = ObjectFactory::createObjectByConfiguredName('node_console_apt_proxy_class');

		// Get a registry
		$applicationInstance = Registry::getRegistry()->getInstance('app');

		// Set the app instance
		$proxyInstance->setApplicationInstance($applicationInstance);

		// Add apt-proxy-specific filters
		$proxyInstance->addExtraFilters($applicationInstance->getControllerInstance(), $responseInstance);

		// Set the apt_proxy instance in registry
		Registry::getRegistry()->addInstance('apt_proxy', $proxyInstance);
	}
}

// [EOF]
?>
