<?php
/**
 * A NodeMessageSelfConnect handler
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class NodeMessageSelfConnectHandler extends BaseMessageHandler implements HandleableMessage, Registerable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set handler name
		$this->setHandlerName('message_self_connect');
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$handlerInstance	An instance of a HandleableMessage class
	 */
	public final static function createNodeMessageSelfConnectHandler () {
		// Get new instance
		$handlerInstance = new NodeMessageSelfConnectHandler();

		// Return the prepared instance
		return $handlerInstance;
	}

	/**
	 * Handles data array of the message
	 *
	 * @param	$messageData		An array with message data to handle
	 * @param	$packageInstance	An instance of a Receivable class
	 * @return	void
	 */
	public function handleMessageData (array $messageData, Receivable $packageInstance) {
		// Get node instance
		$nodeInstance = NodeObjectFactory::createNodeInstance();

		// Are node id and session id the same?
		if (($messageData[XmlSelfConnectTemplateEngine::SELF_CONNECT_DATA_NODE_ID] == $nodeInstance->getNodeId()) && ($messageData[XmlSelfConnectTemplateEngine::SELF_CONNECT_DATA_SESSION_ID] == $nodeInstance->getSessionId())) {
			// Both are equal
			self::createDebugInstance(__CLASS__)->debugOutput('SELF-CONNECT[' . __METHOD__ . ':' . __LINE__ . ']: Have connected to myself, both node and session id are equal!');

			// ... and change state
			$nodeInstance->getStateInstance()->nodeHasSelfConnected();
		} else {
			// Something really horrible happened
			// @TODO Throw an exception here instead of dying
			$this->debugInstance(__METHOD__ . ': ids mismatching! messageData=' . print_r($messageData, TRUE));
		}
	}

	/**
	 * Adds all required elements from given array into data set instance
	 *
	 * @param	$dataSetInstance	An instance of a StoreableCriteria class
	 * @param	$messageData		An array with all message data
	 * @return	void
	 * @throws	UnsupportedOperationException	If this method is called
	 */
	public function addArrayToDataSet (StoreableCriteria $dataSetInstance, array $messageData) {
		// Add generic first
		parent::addArrayToDataSet($dataSetInstance, $messageData);

		// Please don't call this method!
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}

	/**
	 * Initializes configuration data from given message data array
	 *
	 * @param	$messageData	An array with all message data
	 * @return	void
	 * @throws	UnsupportedOperationException	If this method is called
	 */
	protected function initMessageConfigurationData (array $messageData) {
		// Please don't call this method!
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}

	/**
	 * Removes configuration data with given message data array from global configuration
	 *
	 * @param	$messageData	An array with all message data
	 * @return	void
	 * @throws	UnsupportedOperationException	If this method is called
	 */
	protected function removeMessageConfigurationData (array $messageData) {
		// Please don't call this method!
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}
}

// [EOF]
?>
