<?php
/**
 * A NetworkPackageReader task
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class NetworkPackageReaderTask extends BaseTask implements Taskable, Visitable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$taskInstance	An instance of a Taskable/Visitable class
	 */
	public static final function createNetworkPackageReaderTask () {
		// Get new instance
		$taskInstance = new NetworkPackageReaderTask();

		// Return the prepared instance
		return $taskInstance;
	}

	/**
	 * Accepts the visitor to process the visitor
	 *
	 * @param	$visitorInstance	An instance of a Visitor class
	 * @return	void
	 * @todo	Also visit some sub-objects?
	 */
	public function accept (Visitor $visitorInstance) {
		// Visit this task
		$visitorInstance->visitTask($this);
	}

	/**
	 * Executes the task
	 *
	 * @return	void
	 */
	public function executeTask () {
		// "Cache" package instance
		$packageInstance = NetworkPackageFactory::createNetworkPackageInstance();

		// Do we have something to handle?
		if ($packageInstance->isProcessedMessagePending()) {
			/*
			 * A previously proccessed message is waiting for being
			 * "interpreted". This is done by trying to find a configuration
			 * entry based on 'message_type' element.
			 */
			$packageInstance->handleProcessedMessage();
		} elseif ($packageInstance->isNewMessageArrived()) {
			/*
			 * A fully "decoded" message has been received and added for being
			 * processed. Processing a message should not take long, so mostly
			 * this step involves reading all data through a XML template engine
			 * as "XML variables" from the content (which must be a well-formed
			 * XML) and then pushing it on the next stack "processed messages".
			 */
			$packageInstance->handleNewlyArrivedMessage();
		} elseif ($packageInstance->isIncomingRawDataHandled()) {
			/*
			 * Incoming decoded data has been handled (see below) so it needs to
			 * be assembled back to a "package array". Please see NetworkPackage
			 * for further details (what array elements are required et cetera).
			 */
			$packageInstance->assembleDecodedDataToPackage();
		} elseif ($packageInstance->ifMultipleMessagesPending()) {
			/*
			 * Some raw data contained multiple messages which where now splitted.
			 */
			$packageInstance->handleMultipleMessages();
		} elseif ($packageInstance->isNewRawDataPending()) {
			// Raw, decoded data has been received
			$packageInstance->handleIncomingDecodedData();
		} elseif ($packageInstance->ifAssemblerHasPendingDataLeft()) {
			// Handle any pending data from the package assembler
			$packageInstance->handleAssemblerPendingData();
		} // END - if
	}
}

// [EOF]
?>
